listIoTs method
List all IoTs of an OEM
Returns the iot list for the builder identified by the orgid header, and inspect reponse elements for tags "location" "protocol" if some builder have a different application a further header xAuthApp can be added in keycloak and bound to to the OEM like the orgid
Implementation
Future<List<IoT>?> listIoTs() async {
final response = await listIoTsWithHttpInfo();
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
final responseBody = await _decodeBodyBytes(response);
return (await apiClient.deserializeAsync(responseBody, 'List<IoT>')
as List)
.cast<IoT>()
.toList();
}
return null;
}